"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const socketCluster = require("socketcluster-client");
const WampClient_1 = require("./websockets/WampClient");
const HttpApi_1 = require("./HttpApi");
/***
 * LiskClient is a client for the Lisk Core Websocket and HTTP protocol.
 * It maintains a Websocket connection and can call various HTTP endpoints.
 */
class LiskClient {
    constructor(hostname, wsPort, httpPort, query) {
        this.options = {
            hostname: "betanet.lisk.io",
            port: 5001,
            httpPort: 5000,
            query: {},
            connectTimeout: 2000,
            ackTimeout: 2000,
            pingTimeout: 2000,
            autoConnect: true,
            autoReconnect: true,
            autoReconnectOptions: {
                multiplier: 1,
                initialDelay: 5000,
            },
        };
        this.options.hostname = hostname;
        this.options.port = wsPort;
        this.options.httpPort = httpPort;
        this.options.query = query;
        this.http = new HttpApi_1.HttpApi(this.options.hostname, this.options.httpPort);
    }
    connect(connectHandler, closeHandler, errorHandler) {
        // Initiate the connection to the server
        this.socket = socketCluster.create(this.options);
        WampClient_1.WampClient.registerWamp(this.socket);
        this.socket.on("connect", connectHandler);
        this.socket.on("close", closeHandler);
        this.socket.on("error", errorHandler);
    }
    destroy() {
        this.socket.destroy();
    }
    getStatus() {
        return this.socket.call("status");
    }
    getPeers() {
        return this.socket.call("list");
    }
    getBlocks(lasBlockId) {
        return this.socket.call("blocks", { lastId: lasBlockId || "" });
    }
}
exports.LiskClient = LiskClient;
//# sourceMappingURL=LiskClient.js.map