"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const LiskClient_1 = require("./LiskClient");
const nodeHostname = process.env.LISK_NODE_HOSTNAME || "testnet.lisk.io";
const nodeHttpPort = Number.parseInt(process.env.LISK_NODE_PORT || "7000", 10);
const nodeWsPort = Number.parseInt(process.env.LISK_NODE_WSPORT || "7001", 10);
const nodeSecure = !!process.env.LISK_NODE_SECURE;
describe("LiskClient", () => {
    const ownNode = {
        nonce: "g3f97g230fz6dh23",
        nethash: "da3ed6a45429278bac2666961289ca17ad86595d33b31037615d4b8e8f158bba",
        version: "1.1.1",
        os: "linux",
        height: 500,
        wsPort: 7001,
        httpPort: 7000,
    };
    it("can be constructed", () => {
        const client = new LiskClient_1.LiskClient(nodeHostname, nodeWsPort, nodeHttpPort, ownNode);
        chai_1.expect(client).not.to.be.undefined;
    });
    it("can get status via websocket", done => {
        const client = new LiskClient_1.LiskClient(nodeHostname, nodeWsPort, nodeHttpPort, ownNode);
        client.connect(() => __awaiter(this, void 0, void 0, function* () {
            try {
                const status = yield client.getStatus();
                chai_1.expect(status.success).to.be.true;
                chai_1.expect(status.os).to.match(/^linux4/);
                chai_1.expect(status.httpPort).to.eql(nodeHttpPort);
                chai_1.expect(status.height).to.be.within(1, 10000000);
                chai_1.expect(status.broadhash).to.match(/^[0-9a-f]{64}$/);
                chai_1.expect(status.version).to.match(/^1\.2\.[0-9]+-rc.[0-9]+$/);
                chai_1.expect(status.nonce).to.match(/^[0-9a-zA-Z]{16,30}$/);
                done();
            }
            catch (error) {
                done(error);
            }
            finally {
                client.destroy();
            }
        }), () => { }, error => {
            throw new Error(error);
        });
    });
    it("can get peers via websocket", done => {
        const client = new LiskClient_1.LiskClient(nodeHostname, nodeWsPort, nodeHttpPort, ownNode);
        client.connect(() => __awaiter(this, void 0, void 0, function* () {
            try {
                const response = yield client.getPeers();
                chai_1.expect(response.success).to.be.true;
                chai_1.expect(response.peers.length).to.be.within(3, 100);
                for (const peer of response.peers) {
                    chai_1.expect(peer.nonce).to.match(/^[0-9a-zA-Z]{16,30}$/);
                    chai_1.expect(peer.ip).to.match(/^[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+$/);
                    chai_1.expect(peer.wsPort).to.be.within(0, 65535);
                }
                done();
            }
            catch (error) {
                done(error);
            }
            finally {
                client.destroy();
            }
        }), () => { }, error => {
            throw new Error(error);
        });
    });
});
//# sourceMappingURL=LiskClient.spec.js.map